@@ -3,7 +3,7 @@
 import os
 
 from typing import Optional
-from git import Commit, GitCommandError, Repo
+from git import Commit, GitCommandError, Repo, BadName
 
 REPO_PATH = os.getcwd()
 BASE_TAG = "origin/develop"
@@ -48,7 +48,7 @@ def get_commit_safe(sha: str) -> Optional[Commit]:
     repo = Repo(REPO_PATH)
     try:
         return repo.commit(sha)
-    except GitCommandError:
+    except (GitCommandError, BadName):
         return None
 
 
